Class BeginTransactionRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.rdsdata.model.RdsDataRequest
software.amazon.awssdk.services.rdsdata.model.BeginTransactionRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<BeginTransactionRequest.Builder,BeginTransactionRequest>
@Generated("software.amazon.awssdk:codegen")
public final class BeginTransactionRequest
extends RdsDataRequest
implements ToCopyableBuilder<BeginTransactionRequest.Builder,BeginTransactionRequest>
The request parameters represent the input of a request to start a SQL transaction.
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final Stringdatabase()The name of the database.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.final Stringschema()The name of the database schema.final StringThe name or ARN of the secret that enables access to the DB cluster.static Class<? extends BeginTransactionRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
resourceArn
The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
- Returns:
- The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
-
secretArn
The name or ARN of the secret that enables access to the DB cluster.
- Returns:
- The name or ARN of the secret that enables access to the DB cluster.
-
database
The name of the database.
- Returns:
- The name of the database.
-
schema
The name of the database schema.
- Returns:
- The name of the database schema.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<BeginTransactionRequest.Builder,BeginTransactionRequest> - Specified by:
toBuilderin classRdsDataRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-